==> xwxapt-2.2.tar.bz2: xwxapt-2.2/src/shared.h <==
/*
 *  xwxapt: An application to decode APT signals from weather
 *  satellites and produce an image of the weather.
 *
 *  Copyright (C) 2001  Neoklis Kyriazis
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#ifndef SHARED_H
#define SHARED_H		1

#include "common.h"
#include "image.h"
#include "sound.h"

/* Runtime config data */
extern rc_data_t rc_data;

/* Pixel buffer */
extern guchar *gbl_pixel_buf;

extern int
  gbl_sat_type, /* Weather satellite type number   */
  gbl_sync_ref, /* Required position of sync train */
  gbl_sync_err, /* Deviation from sync reference   */
  gbl_duration,	/* Processing duration */
  gbl_line_idx; /* Index to audio samples buffer   */

/* List of required sync position references */
extern int gbl_sync_refs[];

/* Audio/DSP samples buffer */
extern short gbl_line_buffer[];

/* Pixel buffer for display */
extern GdkPixbuf *gbl_pixbuf;

/* Pixbuf rowstride and num of channels */
extern gint
  gbl_rowstride,
  gbl_n_channels;

extern GtkWidget
  *xwxapt_main_window, /* xwxapt's top window   */
  *gbl_text_scroller,  /* Text view scroller    */
  *gbl_level_pbar,     /* Audio level prog. bar */
  *gbl_sync_pbar,      /* Sync level prog. bar  */
  *gbl_status_table,   /* Status widgets' table */
  *gbl_sync_icon,      /* Sync status indicator */
  *gbl_apt_image;      /* Image to be displayed */

/* Text buffer for text view */
extern GtkTextBuffer *gbl_text_buffer;

/* Pixel buffer for display */
extern GdkPixbuf *gbl_pixbuf;

/* Pixbuf rowstride and num of channels */
extern gint
  gbl_rowstride,
  gbl_n_channels;

/* Satellite type names */
extern char *gbl_sat_names[];

extern char
  gbl_samples_file[], /* Samples file name */
  gbl_image_file  []; /* Image files name  */

/* Pointer to samples file */
extern FILE *gbl_samples_fp;

/* Buffer for reading in DSP data */
extern short *gbl_dsp_buffer;

#endif

==> xwxapt-2.4.tar.bz2: xwxapt-2.4/src/shared.h <==
/*
 *  xwxapt: An application to decode APT signals from weather
 *  satellites and produce an image of the weather.
 *
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#ifndef SHARED_H
#define SHARED_H		1

#include "common.h"
#include "image.h"
#include "sound.h"

/* Runtime config data */
extern rc_data_t rc_data;

/* Pixel buffer */
extern guchar *gbl_pixel_buf;

extern int
  gbl_sat_type, /* Weather satellite type number   */
  gbl_sync_ref, /* Required position of sync train */
  gbl_sync_err, /* Deviation from sync reference   */
  gbl_duration,	/* Processing duration */
  gbl_line_idx; /* Index to audio samples buffer   */

/* List of required sync position references */
extern int gbl_sync_refs[];

/* Audio/DSP samples buffer */
extern short gbl_line_buffer[];

/* Pixel buffer for display */
extern GdkPixbuf *gbl_pixbuf;

/* Pixbuf rowstride and num of channels */
extern gint
  gbl_rowstride,
  gbl_n_channels;

extern GtkWidget
  *xwxapt_main_window, /* xwxapt's top window   */
  *gbl_text_scroller,  /* Text view scroller    */
  *gbl_level_pbar,     /* Audio level prog. bar */
  *gbl_sync_pbar,      /* Sync level prog. bar  */
  *gbl_status_table,   /* Status widgets' table */
  *gbl_sync_icon,      /* Sync status indicator */
  *gbl_apt_image;      /* Image to be displayed */

/* Text buffer for text view */
extern GtkTextBuffer *gbl_text_buffer;

/* Pixel buffer for display */
extern GdkPixbuf *gbl_pixbuf;

/* Pixbuf rowstride and num of channels */
extern gint
  gbl_rowstride,
  gbl_n_channels;

/* Satellite type names */
extern char *gbl_sat_names[];

extern char
  gbl_samples_file[MAX_FILE_NAME], /* Samples file name */
  gbl_image_file[MAX_FILE_NAME];   /* Image files name  */

/* Pointer to samples file */
extern FILE *gbl_samples_fp;

/* Buffer for reading in DSP data */
extern short *gbl_dsp_buffer;

#endif
